OC.L10N.register(
    "news",
    {
    "Unread articles" : "Непрочитани статии",
    "News" : "Новости",
    "Download" : "Преземи",
    "Close" : "Затвори",
    "Folder name" : "Име на папка",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Feed exists already!" : "Каналот веќе постои!",
    "New folder" : "Нова папка",
    "Credentials" : "Акредитиви",
    "Subscribe" : "Претплата",
    "Last job ran {relativeTime}." : "Последната процедура се изврши пред {relativeTime}.",
    "Move" : "Премести",
    "Share" : "Сподели",
    "Default" : "Предефиниран",
    "Mark read" : "Означи како прочитано",
    "All articles" : "Сите статии",
    "Starred" : "Со ѕвезда",
    "Settings" : "Параметри",
    "Documentation" : "Документација",
    "Keyboard shortcuts" : "Кратенки преку тастатура",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Newest first" : "Новите прво",
    "Oldest first" : "Старите прво",
    "Mark unread" : "Означи како непрочитано",
    "by" : "од",
    "Open website" : "Отвори вебсајт",
    "Not available" : "Недостапно",
    "Keyboard shortcut" : "Кратенка преку тастатура",
    "right" : "десно",
    "left" : "лево",
    "Refresh" : "Освежи",
    "Load next feed" : "Вчитај следен канал",
    "Shift" : "Shift"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
